UserProfile class

Class that represents the data of the device's owner.

Constructors

UserProfile()

Properties

addresses → List<String>?
Gets the collection of phone numbers of the UserProfile
no setter
fullName → String?
Gets the full name of the UserProfile
no setter
hashCode → int
The hash code for this object.
no setterinherited
photo → Photo?
Gets the full size photo of the UserProfile if any, otherwise returns null.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail → Photo?
Gets the thumbnail representation of the UserProfile photo if any, otherwise returns null.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited